@@ -3,8 +3,8 @@
 #' @description Calculate mean energy
 #'
 #' @param pattern List with reconstructed patterns.
+#' @param weights Weights used to calculate energy. The first number refers to Gest(r), the second number to pcf(r).
 #' @param return_mean Return the mean energy.
-#' @param method String to specifiy if spatial pattern or marks were reconstructed.
 #' @param comp_fast If pattern contains more points than threshold, summary functions are estimated in a computational fast way.
 #' @param verbose Print progress report.
 #'
@@ -31,7 +31,7 @@
 #' \dontrun{
 #' marks_sub <- spatstat::subset.ppp(species_a, select = dbh)
 #' marks_recon <- reconstruct_marks(pattern_random[[1]], marks_sub, n_random = 19, max_runs = 1000)
-#' calculate_energy(marks_recon, return_mean = FALSE, method = "marks")
+#' calculate_energy(marks_recon, return_mean = FALSE)
 #' }
 #'
 #' @aliases calculate_energy
@@ -46,17 +46,22 @@
 
 #' @export
 calculate_energy <- function(pattern,
+                             weights = c(0.5, 0.5),
                              return_mean = FALSE,
-                             method = "spatial",
                              comp_fast = 1000,
                              verbose = TRUE){
 
-  # check if randomized and observed is present
-  if(!all(c(paste0("randomized_", seq_len(length(pattern) - 1)), "observed") == names(pattern)) || is.null(names(pattern))) {
-    stop("Input must named 'randomized_1' to 'randomized_n' and includ 'observed' pattern.",
+  # check if class is correct
+  if (!class(pattern) %in% c("rd_pat", "rd_mar")) {
+    stop("Class of 'pattern' must be 'rd_pat' or 'rd_mar'.",
          call. = FALSE)
   }
 
+  # check if observed pattern is present
+  if (!"observed" %in% names(pattern)) {
+    stop("Input must include 'observed' pattern.", call. = FALSE)
+  }
+
   # extract observed pattern
   pattern_observed <- pattern$observed
 
@@ -69,20 +74,15 @@ calculate_energy <- function(pattern,
                                     lambda = spatstat::intensity.ppp(pattern_observed)),
            length.out = 250)
 
-  if (method == "spatial") {
+  if (class(pattern) == "rd_pat") {
 
-    if(verbose) {
-      # check if pattern is marked
-      if(spatstat::is.marked(pattern_observed) || all(vapply(pattern_reconstructed,
-                                                             spatstat::is.marked,
-                                                             FUN.VALUE = logical(1)))) {
-
-        warning("Only energy of spatial summary functions are considered.", call. = FALSE)
-      }
+    # check if weights make sense
+    if (sum(weights) > 1 || sum(weights) == 0) {
+      stop("The sum of 'weights' must be 0 < sum(weights) <= 1.", call. = FALSE)
     }
 
     # check if number of points exceed comp_fast limit
-    if(pattern_observed$n > comp_fast) {
+    if (pattern_observed$n > comp_fast) {
       comp_fast <- TRUE
     }
 
@@ -91,7 +91,7 @@ calculate_energy <- function(pattern,
     }
 
     # calculate summary functions for observed pattern
-    if(comp_fast) {
+    if (comp_fast) {
 
       gest_observed <- spatstat::Gest(X = pattern_observed,
                                       correction = "none",
@@ -120,7 +120,7 @@ calculate_energy <- function(pattern,
     result <- vapply(seq_along(pattern_reconstructed), function(x) {
 
       # fast computation of summary stats
-      if(comp_fast) {
+      if (comp_fast) {
 
         gest_reconstruction <- spatstat::Gest(X = pattern_reconstructed[[x]],
                                               correction = "none",
@@ -147,12 +147,13 @@ calculate_energy <- function(pattern,
       }
 
       # difference between observed and reconstructed pattern
-      energy <- mean(abs(gest_observed[[3]] - gest_reconstruction[[3]]), na.rm = TRUE) +
-        mean(abs(pcf_observed[[3]] - pcf_reconstruction[[3]]), na.rm = TRUE)
+      energy <- (mean(abs(gest_observed[[3]] - gest_reconstruction[[3]]), na.rm = TRUE) * weights[[1]]) +
+        (mean(abs(pcf_observed[[3]] - pcf_reconstruction[[3]]), na.rm = TRUE) * weights[[2]])
 
       # print progress
-      if(verbose) {
-        message("\r> Progress: ", x, "/", length(pattern_reconstructed), appendLF = FALSE)
+      if (verbose) {
+        message("\r> Progress: ", x, "/", length(pattern_reconstructed), "\t\t",
+                appendLF = FALSE)
       }
 
       return(energy)
@@ -160,15 +161,7 @@ calculate_energy <- function(pattern,
     }, FUN.VALUE = numeric(1))
   }
 
-  else if( method == "marks") {
-
-    # check if pattern is marked
-    if(!spatstat::is.marked(pattern_observed) || !all(vapply(pattern_reconstructed,
-                                                             spatstat::is.marked,
-                                                             FUN.VALUE = logical(1)))) {
-
-      stop("Please provide pattern with reconstruced marks.", call. = FALSE)
-    }
+  else if (class(pattern) == "rd_mar") {
 
     # calculate summary functions
     kmmr_observed <- spatstat::markcorr(pattern_observed,
@@ -183,12 +176,12 @@ calculate_energy <- function(pattern,
                                                 r = r)
 
       # difference between observed and reconstructed pattern
-      energy <- mean(abs(kmmr_observed[[3]] - kmmr_reconstruction[[3]]), na.rm = TRUE) +
-        mean(abs(kmmr_observed[[3]] - kmmr_reconstruction[[3]]), na.rm = TRUE)
+      energy <- mean(abs(kmmr_observed[[3]] - kmmr_reconstruction[[3]]), na.rm = TRUE)
 
       # print progress
-      if(verbose) {
-        message("\r> Progress: ", x, "/", length(pattern_reconstructed), appendLF = FALSE)
+      if (verbose) {
+        message("\r> Progress: ", x, "/", length(pattern_reconstructed), "\t\t",
+                appendLF = FALSE)
       }
 
       return(energy)
@@ -196,18 +189,13 @@ calculate_energy <- function(pattern,
     }, FUN.VALUE = numeric(1))
   }
 
-  else {
-    stop("Please select either 'method = spatial' or 'method = marks'.",
-         call. = FALSE)
-  }
-
   # return mean for all reconstructed patterns
-  if(return_mean) {
+  if (return_mean) {
     result <- mean(result)
   }
 
   # write result in new line if progress was printed
-  if(verbose) {
+  if (verbose) {
     message("\r")
   }
 
